@@ -7,7 +7,7 @@ def main():
 	data = response.json()
 
 	if data['status_code'] == 1: # Up
-		print('\n 🐈  It\'s up. Go back to work!')
+		print('\n 😊  It\'s up.')
 
 	if data['status_code'] == 2: # Down
-		print('\n 🦄  It\'s down. Go outside!')
+		print('\n 😞  It\'s down.')
